unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
From: Leo Famulari <leo@famulari.name>
To: guix-devel@gnu.org
Subject: [PATCH 4/5] gnu: letsencrypt: Generate and install documentation.
Date: Wed, 17 Feb 2016 22:53:52 -0500	[thread overview]
Message-ID: <ab7f1911783ac4dcb9092da15cec9f3f71b8e5f5.1455767577.git.leo@famulari.name> (raw)
In-Reply-To: <cover.1455767577.git.leo@famulari.name>
In-Reply-To: <cover.1455767577.git.leo@famulari.name>

* gnu/packages/tls.scm (letsencrypt)[arguments]: Add 'docs' phase.
[native-inputs]: Add python2-sphinx, python2-sphinx-rtd-theme,
python2-sphinx-repoze-autointerface,
python2-sphinxcontrib-programoutput, texinfo.
---
 gnu/packages/tls.scm | 28 +++++++++++++++++++++++++---
 1 file changed, 25 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/tls.scm b/gnu/packages/tls.scm
index 3aca5f3..00d4805 100644
--- a/gnu/packages/tls.scm
+++ b/gnu/packages/tls.scm
@@ -375,11 +375,33 @@ security, and applying best practice development processes.")
                 "1wwq8yvfdybf4d0gv4yfddkrg865s7rhng5xg563kks4wza1a2wp"))))
     (build-system python-build-system)
     (arguments
-     `(#:python ,python-2))
-    ;; TODO: Add optional inputs for testing building documentation.
+     `(#:python ,python-2
+       #:phases
+       (modify-phases %standard-phases
+         (add-after 'install 'docs
+           (lambda* (#:key outputs #:allow-other-keys)
+             (let* ((out (assoc-ref outputs "out"))
+                    (man1 (string-append out "/share/man/man1"))
+                    (man7 (string-append out "/share/man/man7"))
+                    (info (string-append out "/info")))
+               (substitute* "docs/man/letsencrypt.rst"
+                 (("letsencrypt --help all")
+                  (string-append out "/bin/letsencrypt" " --help all")))
+               (and
+                 (zero? (system* "make" "-C" "docs" "man" "info"))
+                 (install-file "docs/_build/texinfo/LetsEncrypt.info" info)
+                 (install-file "docs/_build/man/letsencrypt.1" man1)
+                 (install-file "docs/_build/man/letsencrypt.7" man7))))))))
+    ;; TODO: Add optional inputs for testing.
     (native-inputs
      `(("python2-nose" ,python2-nose)
-       ("python2-mock" ,python2-mock)))
+       ("python2-mock" ,python2-mock)
+       ;; For documentation
+       ("python2-sphinx" ,python2-sphinx)
+       ("python2-sphinx-rtd-theme" ,python2-sphinx-rtd-theme)
+       ("python2-sphinx-repoze-autointerface" ,python2-sphinx-repoze-autointerface)
+       ("python2-sphinxcontrib-programoutput" ,python2-sphinxcontrib-programoutput)
+       ("texinfo" ,texinfo)))
     (propagated-inputs
      `(("python2-acme" ,python2-acme)
        ("python2-zope-interface" ,python2-zope-interface)
-- 
2.6.3

  parent reply	other threads:[~2016-02-18  3:54 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-02-18  3:53 [PATCH 0/5] Install docs for Let's Encrypt Leo Famulari
2016-02-18  3:53 ` [PATCH 1/5] gnu: Add python-sphinxcontrib-programoutput Leo Famulari
2016-02-18  3:53 ` [PATCH 2/5] licenses: Add repoze license Leo Famulari
2016-02-18  3:53 ` [PATCH 3/5] gnu: Add python-sphinx-repoze-autointerface Leo Famulari
2016-02-18  8:28   ` Alex Kost
2016-02-18 17:40     ` Leo Famulari
2016-02-18  3:53 ` Leo Famulari [this message]
2016-02-18  3:53 ` [PATCH 5/5] gnu: python-acme: Generate and install documentation Leo Famulari
2016-02-18 12:51   ` Ricardo Wurmus
2016-02-18 17:46     ` Leo Famulari
2016-02-18 19:36       ` Andreas Enge
2016-02-20  7:48 ` [PATCH 0/5] Install docs for Let's Encrypt Leo Famulari

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://guix.gnu.org/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=ab7f1911783ac4dcb9092da15cec9f3f71b8e5f5.1455767577.git.leo@famulari.name \
    --to=leo@famulari.name \
    --cc=guix-devel@gnu.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).